package com.sooka.system.medicine.industry.mapper;


import com.sooka.system.medicine.industry.domain.TGuijiMedicineIndustry;

import java.util.List;

/**
 * 规上工业经济数据Mapper接口
 *
 * @author lei
 * @date 2022-08-22
 */
public interface TGuijiMedicineIndustryMapper
{
    /**
     * 查询规上工业经济数据
     *
     * @param id 规上工业经济数据ID
     * @return 规上工业经济数据
     */
    public TGuijiMedicineIndustry selectTGuijiMedicineIndustryById(String id);

    /**
     * 查询规上工业经济数据列表
     *
     * @param tGuijiMedicineIndustry 规上工业经济数据
     * @return 规上工业经济数据集合
     */
    public List<TGuijiMedicineIndustry> selectTGuijiMedicineIndustryList(TGuijiMedicineIndustry tGuijiMedicineIndustry);

    /**
     * 新增规上工业经济数据
     *
     * @param tGuijiMedicineIndustry 规上工业经济数据
     * @return 结果
     */
    public int insertTGuijiMedicineIndustry(TGuijiMedicineIndustry tGuijiMedicineIndustry);

    /**
     * 修改规上工业经济数据
     *
     * @param tGuijiMedicineIndustry 规上工业经济数据
     * @return 结果
     */
    public int updateTGuijiMedicineIndustry(TGuijiMedicineIndustry tGuijiMedicineIndustry);

    /**
     * 删除规上工业经济数据
     *
     * @param id 规上工业经济数据ID
     * @return 结果
     */
    public int deleteTGuijiMedicineIndustryById(String id);

    /**
     * 批量删除规上工业经济数据
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTGuijiMedicineIndustryByIds(String[] ids);
}
